@@ -1,4 +1,6 @@
-use crate::{shared::MetadataFindInput, APIResponse, BaseClient, TimePlan, ID};
+use crate::{
+    shared::MetadataFindInput, APIResponse, BaseClient, TimePlan, ID,
+};
 use nettu_scheduler_api_structs::*;
 use nettu_scheduler_domain::{BusyCalendar, Metadata};
 use reqwest::StatusCode;
@@ -32,6 +34,14 @@ pub struct UpdateServiceUserInput {
     pub furthest_booking_time: Option<i64>,
 }
 
+pub struct CreateBookingIntendInput {
+    pub service_id: ID,
+    pub host_user_id: Option<ID>,
+    pub timestamp: i64,
+    pub duration: i64,
+    pub interval: i64,
+}
+
 pub struct RemoveServiceUserInput {
     pub service_id: ID,
     pub user_id: ID,
@@ -85,6 +95,25 @@ impl ServiceClient {
             .await
     }
 
+    pub async fn create_booking_intend(
+        &self,
+        input: CreateBookingIntendInput,
+    ) -> APIResponse<create_service_event_intend::APIResponse> {
+        let body = create_service_event_intend::RequestBody {
+            duration: input.duration,
+            host_user_id: input.host_user_id,
+            interval: input.interval,
+            timestamp: input.timestamp,
+        };
+        self.base
+            .post(
+                body,
+                format!("service/{}/booking-intend", input.service_id),
+                StatusCode::OK,
+            )
+            .await
+    }
+
     pub async fn delete(&self, service_id: ID) -> APIResponse<delete_service::APIResponse> {
         self.base
             .delete(format!("service/{}", service_id), StatusCode::OK)
