@@ -56,7 +56,7 @@ impl UserClient {
         self.base
             .post(
                 body,
-                format!("user/{:?}/oauth/google", user_id),
+                format!("user/{}/oauth/google", user_id.to_string()),
                 StatusCode::OK,
             )
             .await
